@@ -43,12 +43,12 @@ espn_wnba_game_all <- function(game_id){
       
       
       plays <- raw_play_df[["plays"]] %>%
-        tidyr::unnest_wider(unlist(.data$participants))
+        tidyr::unnest_wider(.data$participants)
       suppressWarnings(
         aths <- plays %>%
           dplyr::group_by(.data$id) %>%
           dplyr::select(.data$id, .data$athlete.id) %>%
-          tidyr::unnest_wider(unlist(.data$athlete.id, use.names=FALSE),names_sep = "_")
+          tidyr::unnest_wider(.data$athlete.id,names_sep = "_")
       )
       names(aths)<-c("play.id","athlete.id.1","athlete.id.2","athlete.id.3")
       plays_df <- dplyr::bind_cols(plays, aths) %>%
@@ -184,7 +184,10 @@ espn_wnba_game_all <- function(game_id){
 #' @import rvest
 #' @export
 #' @examples
-#' espn_wnba_pbp(game_id = 401244185)
+#' 
+#' \donttest{
+#'   try(espn_wnba_pbp(game_id = 401244185))
+#' }
 espn_wnba_pbp <- function(game_id){
   old <- options(list(stringsAsFactors = FALSE, scipen = 999))
   on.exit(options(old))
@@ -207,12 +210,12 @@ espn_wnba_pbp <- function(game_id){
   raw_play_df <- jsonlite::fromJSON(jsonlite::toJSON(raw_play_df),flatten=TRUE)
   #---- Play-by-Play ------
   plays <- raw_play_df[["plays"]] %>%
-    tidyr::unnest_wider(unlist(.data$participants, use.names=FALSE))
+    tidyr::unnest_wider(.data$participants)
   suppressWarnings(
     aths <- plays %>%
       dplyr::group_by(.data$id) %>%
       dplyr::select(.data$id, .data$athlete.id) %>%
-      tidyr::unnest_wider(unlist(.data$athlete.id, use.names=FALSE),names_sep = ".")
+      tidyr::unnest_wider(.data$athlete.id,names_sep = ".")
   )
   names(aths)<-c("play.id","athlete.id.1","athlete.id.2","athlete.id.3")
   plays_df <- dplyr::bind_cols(plays, aths) %>%
@@ -234,7 +237,10 @@ espn_wnba_pbp <- function(game_id){
 #' @import rvest
 #' @export
 #' @examples
-#' espn_wnba_team_box(game_id = 401244185)
+#' 
+#' \donttest{
+#'   try(espn_wnba_team_box(game_id = 401244185))
+#' }
 espn_wnba_team_box <- function(game_id){
   old <- options(list(stringsAsFactors = FALSE, scipen = 999))
   on.exit(options(old))
@@ -338,7 +344,10 @@ espn_wnba_team_box <- function(game_id){
 #' @import rvest
 #' @export
 #' @examples
-#' espn_wnba_player_box(game_id = 401244185)
+#' \donttest{
+#'   try(espn_wnba_player_box(game_id = 401244185))
+#' }
+#' 
 espn_wnba_player_box <- function(game_id){
   old <- options(list(stringsAsFactors = FALSE, scipen = 999))
   on.exit(options(old))
@@ -402,7 +411,9 @@ espn_wnba_player_box <- function(game_id){
 #' @import rvest
 #' @export
 #' @examples
-#' espn_wnba_teams()
+#' \donttest{
+#'   try(espn_wnba_teams())
+#' }
 
 espn_wnba_teams <- function(){
   old <- options(list(stringsAsFactors = FALSE, scipen = 999))
@@ -421,7 +432,7 @@ espn_wnba_teams <- function(){
   ## game_id
   leagues <- jsonlite::fromJSON(resp)[["sports"]][["leagues"]][[1]][['teams']][[1]][['team']] %>%
     dplyr::group_by(.data$id) %>%
-    tidyr::unnest_wider(unlist(.data$logos, use.names=FALSE),names_sep = "_") %>%
+    tidyr::unnest_wider(.data$logos,names_sep = "_") %>%
     tidyr::unnest_wider(.data$logos_href,names_sep = "_") %>%
     dplyr::select(-.data$logos_width,-.data$logos_height,
                   -.data$logos_alt, -.data$logos_rel) %>%
@@ -467,11 +478,10 @@ espn_wnba_teams <- function(){
 #' @import rvest
 #' @export
 #' @examples
-#' # Get schedule from 2020 season (returns 1000 results, max allowable.)
-#' # Must iterate through dates to get full year's schedule, as below:
-#' espn_wnba_scoreboard (season = 2020)
 #' # Get schedule from date 2020-08-29
-#' espn_wnba_scoreboard (season = "20200829")
+#' \donttest{
+#'   try(espn_wnba_scoreboard (season = "20200829"))
+#' }
 
 espn_wnba_scoreboard <- function(season){
   
@@ -582,8 +592,8 @@ espn_wnba_scoreboard <- function(season){
 #' @importFrom data.table rbindlist
 #' @export
 #' @examples
-#' \dontrun{
-#' espn_wnba_standings(year = 2021)
+#' \donttest{
+#'   try(espn_wnba_standings(year = 2021))
 #' }
 espn_wnba_standings <- function(year){
   
